Discrete
============================

.. autoclass:: sdgx.data_models.inspectors.discrete.DiscreteInspector
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance:
    :private-members:
